# SynackAPI

This is a python package which aims to provide Synack Red Team members an easy way to interact with the Synack API.

I am in no way affiliated with Synack other than being a Synack Red Team member myself.
This project may completely break or become unusable at any time through no fault of my own.

Additionally, it is possible to use this to do stupid things that may have you suffer consequences.
Be familiar with what this tool is doing or don't use it.
I am not responsible if you get yourself in trouble.

# Documentation

For the most up to date information, please check out the mdBook at the link below:

https://bamhm182.github.io/SynackAPI
